@@ -7,7 +7,7 @@ use warnings;
 
 use Carp;
 
-our $VERSION = '0.002_01';
+our $VERSION = '0.001';
 
 use constant REF_ARRAY			=> ref [];
 
@@ -351,7 +351,7 @@ sub __midnight {
 
 =head2 __normalize_capture
 
- my $normalized_capture = $dmad->__normalize_capture( $capture_name, $capture_content );
+ my $normalized_capture = $dmad->__normalize_key( $capture_name, $capture_content );
 
 This method is called by L<__event_capture()|/__event_capture> when a
 string is captured.  The arguments are the capture name and its
@@ -681,7 +681,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2021-2022 by Thomas R. Wyant, III
+Copyright (C) 2021 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
